tlslite.constants.HandshakeType

Package tlslite :: Module constants :: Class HandshakeType |
[hide private]
[frames] | no frames]

# Class HandshakeType

source code

Class Variables | [hide private]
| certificate = `11`
| certificate_request = `13`
| certificate_verify = `15`
| client_hello = `1`
| client_key_exchange = `16`
| finished = `20`
| hello_request = `0`
| next_protocol = `67`
| server_hello = `2`
| server_hello_done = `14`
| server_key_exchange = `12`